@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '0.011_1'; # VERSION
+our $VERSION = '0.014_01'; # VERSION
 
 
 
@@ -35,17 +35,31 @@ sub _open
     return $hdl;
 }
 
-sub _identify_fh
+sub _identify_handle
 {
-    my ($identifier, $fh, $format, $languages) = @_;
-    my $result = $identifier->identify_handle($fh);
-    _print_result($result, $format, $languages);
+    my ($identifier, $fh, $format, $languages, $each_line) = @_;
+    if ( $each_line ) {
+        while (<$fh>) {
+            chomp;
+            _identify_string($identifier, $_, $format, $languages);
+        }
+    } else {
+        my $result = $identifier->identify_handle($fh);
+        _print_result($result, $format, $languages);
+    }
 }
 
 sub _identify
 {
-    my ($identifier, $file, $format, $languages) = @_;
-    my $result = $identifier->identify_file($file);
+    my ($identifier, $file, $format, $languages, $each_line) = @_;
+    my $fh = Lingua::YALI::_open($file);
+    _identify_handle($identifier, $fh, $format, $languages, $each_line);
+}
+
+sub _identify_string
+{
+    my ($identifier, $string, $format, $languages) = @_;
+    my $result = $identifier->identify_string($string);
     _print_result($result, $format, $languages);
 }
 
@@ -68,22 +82,25 @@ sub _print_result
     } else {
         croak("Unsupported format $format");
     }
-    
+
     print $line . "\n";
 }
 
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Lingua::YALI - YALI - Yet Another Language Identifier.
 
 =head1 VERSION
 
-version 0.011_1
+version 0.014_01
 
 =head1 SYNOPSIS
 
@@ -111,11 +128,11 @@ More information can be found at the L<YALI homepage|http://ufal.mff.cuni.cz/~ma
 
 =over
 
-=item * L<yali-language-identifier|Lingua::YALI::yali-language-identifier> - tool for a language identification with pretrained models
+=item * L<yali-language-identifier|bin/yali-language-identifier> - tool for a language identification with pretrained models
 
-=item * L<yali-builder|Lingua::YALI::yali-builder> - tool for a building custom language models.
+=item * L<yali-builder|bin/yali-builder> - tool for a building custom language models.
 
-=item * L<yali-identifier|Lingua::YALI::yali-identifier> - tool for a language identification with custom language models.
+=item * L<yali-identifier|bin/yali-identifier> - tool for a language identification with custom language models.
 
 =back
 
@@ -137,10 +154,10 @@ More information can be found at the L<YALI homepage|http://ufal.mff.cuni.cz/~ma
 
 =item * L<Lingua::Lid|Lingua::Lid> can recognize 45 languages and returns only the most probable result without any weight.
 
-=item * L<Lingua::Ident|Lingua::Ident> requires training files, so it is similar to L<Lingua::YALI::LanguageIdentifier|Lingua::YALI::LanguageIdentifier>, 
+=item * L<Lingua::Ident|Lingua::Ident> requires training files, so it is similar to L<Lingua::YALI::LanguageIdentifier|Lingua::YALI::LanguageIdentifier>,
 but it does not provide any options for constructing models.
 
-=item * L<Lingua::Identify|Lingua::Identify> can recognize 33 languages but it does not allows you to use different models. 
+=item * L<Lingua::Identify|Lingua::Identify> can recognize 33 languages but it does not allows you to use different models.
 
 =back
 
@@ -156,5 +173,16 @@ This is free software, licensed under:
 
   The (three-clause) BSD License
 
-=cut
+=head1 AUTHOR
 
+Martin Majlis <martin@majlis.cz>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Martin Majlis.
+
+This is free software, licensed under:
+
+  The (three-clause) BSD License
+
+=cut
