@@ -8,7 +8,7 @@ use Carp;
 use PerlIO::gzip;
 use Lingua::YALI;
 
-our $VERSION = '0.011_1'; # VERSION
+our $VERSION = '0.014_01'; # VERSION
 
 # hash with paths to models
 # format: { 'class1' => 'file1', 'class2' => 'file2' }
@@ -75,7 +75,7 @@ sub add_class
 
 sub remove_class
 {
-    my ( $self, $class, $file ) = @_;
+    my ( $self, $class ) = @_;
 
     if ( defined( $self->{_model_file}->{$class} ) ) {
         $self->_unload_model($class);
@@ -116,7 +116,7 @@ sub identify_string
     if ( ! defined($string) ) {
         return;
     }
-    
+
     my $result = $self->identify_handle($fh);
 
     close($fh);
@@ -127,7 +127,7 @@ sub identify_string
 
 sub identify_handle
 {
-    my ($self, $fh, $verbose) = @_;
+    my ($self, $fh) = @_;
     my %actRes = ();
 
     # parameter check
@@ -184,23 +184,15 @@ sub identify_handle
 
     # normalize results
     my @res = ();
-    if ( $sum > 0 ) {
-        for my $l (@allLanguages) {
-            my $score = 0;
-            if ( defined($actRes{$l}) ) {
-                $score = $actRes{$l};
-            }
-            my @pair = ($l, $score / $sum);
-            push(@res, \@pair);
-        }
-    }
 
-#    print STDERR "\nX\n" . $res[0] . "\nX\n";
-#    print STDERR "\nX\n\t" . $res[0]->[0] . "\nX\n";
-#    print STDERR "\nX\n\t" . $res[0]->[1] . "\nX\n";
-#    print STDERR "\nY\n" . $res[1] . "\nY\n";
-#    print STDERR "\nY\n\t" . $res[1]->[0] . "\nY\n";
-#    print STDERR "\nY\n\t" . $res[1]->[1] . "\nY\n";
+    for my $l (@allLanguages) {
+        my $score = 0;
+        if ( defined($actRes{$l}) ) {
+            $score = $actRes{$l} / $sum;
+        }
+        my @pair = ($l, $score);
+        push(@res, \@pair);
+    }
 
     # sort according to score
     my @sortedRes = sort { $b->[1] <=> $a->[1] } @res;
@@ -292,15 +284,18 @@ sub _unload_model
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Lingua::YALI::Identifier - Module for language identification with custom models.
 
 =head1 VERSION
 
-version 0.011_1
+version 0.014_01
 
 =head1 SYNOPSIS
 
@@ -448,5 +443,16 @@ This is free software, licensed under:
 
   The (three-clause) BSD License
 
-=cut
+=head1 AUTHOR
 
+Martin Majlis <martin@majlis.cz>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Martin Majlis.
+
+This is free software, licensed under:
+
+  The (three-clause) BSD License
+
+=cut
