@@ -8,7 +8,7 @@ use File::Glob;
 use Carp;
 use Moose;
 
-our $VERSION = '0.011_1'; # VERSION
+our $VERSION = '0.014_01'; # VERSION
 
 extends 'Lingua::YALI::Identifier';
 
@@ -73,11 +73,12 @@ sub get_languages
 sub get_available_languages
 {
     my $self = shift;
-    
+
     # Get a module's shared files directory
     if ( ! defined($self->_languages) ) {
 
-        my $dir = File::ShareDir::dist_dir('Lingua-YALI');
+        my $dir = "share/";
+        eval { $dir = File::ShareDir::dist_dir('Lingua-YALI'); };
 
         my @languages = ();
 
@@ -107,15 +108,18 @@ sub get_available_languages
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Lingua::YALI::LanguageIdentifier - Module for language identification.
 
 =head1 VERSION
 
-version 0.011_1
+version 0.014_01
 
 =head1 SYNOPSIS
 
@@ -479,4 +483,3 @@ This is free software, licensed under:
   The (three-clause) BSD License
 
 =cut
-
